<?php

namespace Lol\Lol2345\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Lol\Lol2345\Http\Requests\GroupRequest;
use Lol\Lol2345\Models\Group;

/**
 * Admin web controller class.
 */
class GroupWorkflowController extends BaseController
{

    /**
     * Workflow controller function for group.
     *
     * @param Model   $group
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(GroupRequest $request, Group $group, $step)
    {

        try {

            $group->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('lol2345::group.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/group/group/' . $group->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/group/group/' . $group->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for group.
     *
     * @param Model   $group
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Group $group, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $group->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('lol2345::group.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lol2345::admin.group.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lol2345::admin.group.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lol2345::admin.group.message', $data)->render();

        }

    }
}
