<?php

namespace Lol\Lol2345\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Lol\Lol2345\Models\Group;

class GroupAction
{
    /**
     * Perform the complete action.
     *
     * @param Group $group
     *
     * @return Group
     */
    public function complete(Group $group)
    {
        try {
            $group->status = 'complete';
            return $group->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Group $group
     *
     * @return Group
     */public function verify(Group $group)
    {
        try {
            $group->status = 'verify';
            return $group->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Group $group
     *
     * @return Group
     */public function approve(Group $group)
    {
        try {
            $group->status = 'approve';
            return $group->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Group $group
     *
     * @return Group
     */public function publish(Group $group)
    {
        try {
            $group->status = 'publish';
            return $group->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Group $group
     *
     * @return Group
     */
    public function archive(Group $group)
    {
        try {
            $group->status = 'archive';
            return $group->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Group $group
     *
     * @return Group
     */
    public function unpublish(Group $group)
    {
        try {
            $group->status = 'unpublish';
            return $group->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
