<?php

namespace Lol\Lol2345\Workflow;

use Lol\Lol2345\Models\Group;
use Validator;

class GroupValidator
{

    /**
     * Determine if the given group is valid for complete status.
     *
     * @param Group $group
     *
     * @return bool / Validator
     */
    public function complete(Group $group)
    {
        return Validator::make($group->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given group is valid for verify status.
     *
     * @param Group $group
     *
     * @return bool / Validator
     */
    public function verify(Group $group)
    {
        return Validator::make($group->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given group is valid for approve status.
     *
     * @param Group $group
     *
     * @return bool / Validator
     */
    public function approve(Group $group)
    {
        return Validator::make($group->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given group is valid for publish status.
     *
     * @param Group $group
     *
     * @return bool / Validator
     */
    public function publish(Group $group)
    {
        return Validator::make($group->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given group is valid for archive status.
     *
     * @param Group $group
     *
     * @return bool / Validator
     */
    public function archive(Group $group)
    {
        return Validator::make($group->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given group is valid for unpublish status.
     *
     * @param Group $group
     *
     * @return bool / Validator
     */
    public function unpublish(Group $group)
    {
        return Validator::make($group->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
